@@ -1,4 +1,3 @@
-# !/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
 Created on Wed Oct 31 16:23:13 2018
@@ -27,9 +26,7 @@ from maestral.constants import (
 )
 from maestral.daemon import (
     start_maestral_daemon_process,
-    start_maestral_daemon,
     stop_maestral_daemon_process,
-    get_maestral_pid,
     get_maestral_proxy,
     Start,
     Pyro5
@@ -182,22 +179,18 @@ class MaestralGuiApp(QtWidgets.QSystemTrayIcon):
 
     def get_or_start_maestral_daemon(self):
 
-        pid = get_maestral_pid(self.config_name)
-        if pid:
-            self._started = False
-        else:
-            res = start_maestral_daemon_process(self.config_name)
+        res = start_maestral_daemon_process(self.config_name)
 
-            if res == Start.Failed:
-                title = 'Could not start Maestral'
-                message = ('Could not start or connect to sync daemon. Please try again '
-                           'and contact the developer if this issue persists.')
-                show_dialog(title, message, level='error')
-                self.quit()
-            elif res == Start.AlreadyRunning:
-                self._started = False
-            elif res == Start.Ok:
-                self._started = True
+        if res == Start.Failed:
+            title = 'Could not start Maestral'
+            message = ('Could not start or connect to sync daemon. Please try again '
+                       'and contact the developer if this issue persists.')
+            show_dialog(title, message, level='error')
+            self.quit()
+        elif res == Start.AlreadyRunning:
+            self._started = False
+        elif res == Start.Ok:
+            self._started = True
 
         return get_maestral_proxy(self.config_name)
 
@@ -639,30 +632,3 @@ def run(config_name='maestral'):
     maestral_gui = MaestralGuiApp(config_name)
     maestral_gui.load_maestral()
     sys.exit(app.exec())
-
-
-def run_cli():
-    """
-    This is the main entry point for frozen executables.
-    If only the --config-name option is given, it starts the GUI with the given config.
-    If the --cli option is given, all following arguments will be passed to the CLI.
-    If the --frozen-daemon option is given, an idle maestral daemon is started. This is to
-    support launching the daemon from frozen executables as produced for instance by
-    PyInstaller.
-    """
-    import argparse
-
-    parser = argparse.ArgumentParser()
-    parser.add_argument('-c', '--config-name', help='Configuration name', default='maestral')
-    parser.add_argument('--cli', action='store_true', help='Forward calls to CLI.')
-    parser.add_argument('--frozen-daemon', action='store_true', help='Start daemon only')
-    parsed_args, remaining = parser.parse_known_args()
-
-    if parsed_args.cli:
-        sys.argv = ['maestral'] + remaining + ['-c', parsed_args.config_name]
-        from maestral.cli import main
-        main()
-    elif parsed_args.frozen_daemon:
-        start_maestral_daemon(parsed_args.config_name)
-    else:
-        run(parsed_args.config_name)
