@@ -14,23 +14,24 @@ from distutils.version import LooseVersion
 from PyQt5 import QtGui, QtCore, QtWidgets, uic
 
 # maestral modules
-from maestral import __version__, __author__, __url__
+from maestral import __version__ as __daemon_version__
 from maestral.utils.appdirs import get_home_dir
 from maestral.utils.notify import FILECHANGE, SYNCISSUE
 from maestral.utils.autostart import AutoStart
 
 # local imports
+from . import __version__, __author__, __url__
 from .selective_sync_dialog import SelectiveSyncDialog
-from .resources import (get_native_item_icon, UNLINK_DIALOG_PATH,
-                        SETTINGS_WINDOW_PATH, APP_ICON_PATH, FACEHOLDER_PATH)
+from .resources import (
+    native_item_icon, UNLINK_DIALOG_PATH,
+    SETTINGS_WINDOW_PATH, APP_ICON_PATH, FACEHOLDER_PATH
+)
 from .utils import (
-    IS_MACOS,
-    UserDialog,
-    get_scaled_font, isDarkWindow, center_window,
-    LINE_COLOR_DARK, LINE_COLOR_LIGHT,
+    IS_MACOS, LINE_COLOR_DARK, LINE_COLOR_LIGHT,
+    get_scaled_font, is_dark_window, center_window,
     icon_to_pixmap, get_masked_image, MaestralBackgroundTask
 )
-
+from .widgets import UserDialog
 
 NEW_QT = LooseVersion(QtCore.QT_VERSION_STR) >= LooseVersion('5.11')
 
@@ -74,8 +75,11 @@ class SettingsWindow(QtWidgets.QWidget):
     def __init__(self, parent, mdbx):
         super().__init__()
         uic.loadUi(SETTINGS_WINDOW_PATH, self)
+
         if IS_MACOS:
+            # noinspection PyTypeChecker
             self.setWindowFlags(self.windowFlags() | QtCore.Qt.WindowStaysOnTopHint)
+
         self._parent = parent
         self.update_dark_mode()
 
@@ -118,7 +122,7 @@ class SettingsWindow(QtWidgets.QWidget):
         self.dropbox_folder_dialog.setModal(True)
         self.dropbox_folder_dialog.setAcceptMode(QtWidgets.QFileDialog.AcceptOpen)
         self.dropbox_folder_dialog.setFileMode(QtWidgets.QFileDialog.Directory)
-        self.dropbox_folder_dialog.setOption(QtWidgets.QFileDialog.ShowDirsOnly, True)
+        self.dropbox_folder_dialog.setOption(QtWidgets.QFileDialog.ShowDirsOnly)
         self.dropbox_folder_dialog.fileSelected.connect(self.on_new_dbx_folder)
         self.dropbox_folder_dialog.rejected.connect(
                 lambda: self.comboBoxDropboxPath.setCurrentIndex(0))
@@ -135,7 +139,7 @@ class SettingsWindow(QtWidgets.QWidget):
         # populate sync section
         parent_dir = osp.split(self.mdbx.dropbox_path)[0]
         relative_path = self.rel_path(parent_dir)
-        folder_icon = get_native_item_icon(parent_dir)
+        folder_icon = native_item_icon(parent_dir)
 
         self.comboBoxDropboxPath.clear()
         self.comboBoxDropboxPath.addItem(folder_icon, relative_path)
@@ -155,7 +159,7 @@ class SettingsWindow(QtWidgets.QWidget):
 
         # populate about section
         year = time.localtime().tm_year
-        self.labelVersion.setText(self.labelVersion.text().format(__version__))
+        self.labelVersion.setText(self.labelVersion.text().format(__version__, __daemon_version__))
         self.labelUrl.setText(self.labelUrl.text().format(__url__))
         self.labelCopyright.setText(self.labelCopyright.text().format(year, __author__))
 
@@ -226,7 +230,7 @@ class SettingsWindow(QtWidgets.QWidget):
                 self.mdbx.resume_sync()
             else:
                 self.comboBoxDropboxPath.setItemText(0, self.rel_path(new_location))
-                self.comboBoxDropboxPath.setItemIcon(0, get_native_item_icon(new_location))
+                self.comboBoxDropboxPath.setItemIcon(0, native_item_icon(new_location))
 
     @QtCore.pyqtSlot(int)
     def on_start_on_login_clicked(self, state):
@@ -258,7 +262,7 @@ class SettingsWindow(QtWidgets.QWidget):
             self.update_dark_mode()
 
     def update_dark_mode(self):
-        rgb = LINE_COLOR_DARK if isDarkWindow() else LINE_COLOR_LIGHT
+        rgb = LINE_COLOR_DARK if is_dark_window() else LINE_COLOR_LIGHT
         line_style = 'color: rgb({0}, {1}, {2})'.format(*rgb)
 
         self.line0.setStyleSheet(line_style)
